aos CUBE is the name of the `aos <http://aos.io>`_ command line tool, packaged as aos-cube, which enables the full aos workflow: repositories version control, maintaining dependencies, publishing code, updating from remotely hosted repositories, and invoking MXCHIP aos's own build system and export functions, among other operations.

## Installation

aos CUBE is a Python script, so you'll need Python installed in order to use it. aos CUBE was tested with Python 2.7.

aos CUBE supports Git repositories, so you'll also need to install Git.

## Get Started

The best way to get started is to `read the documentation on <https://code.aliyun.com/aos/aos-cube/README.md>`_.

## License

aos CUBE is licensed under Apache-2.0
